### Instructions

Please go through the following checklist before submitting the PR:

- [ ] Provide an overview of the changes you're making and explain why you're proposing them.

- [ ] Include `Fixes #NNN` or `Closes #NNN` somewhere in the description if this PR addresses an existing issue.

- [ ] If this PR is not complete, select "Create Draft Pull Request" in the pull request button's menu.

  Consider using a task list (e.g., `- [ ] add tests ...`) to indicate remaining to-do items.

- [ ] If you would like to list yourself as a DataLad contributor and your name is not mentioned please modify .zenodo.json file.

- [ ] **Delete these instructions**. :-)

Thanks for contributing!
